# SimilarityFunction

Enum class for supported score functions. The following functions are supported: - ``SimilarityFunction.MAXSIM`` (``"MaxSim"``): Max similarity



## Parameters

- **value**

- **names** – defaults to `None`

- **module** – defaults to `None`

- **qualname** – defaults to `None`

- **type** – defaults to `None`

- **start** – defaults to `1`

- **boundary** – defaults to `None`
